<?php
namespace Teknisa\CTB\Controllers;

use Teknisa\Libs\Util\Environment;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request\Row;
use Teknisa\CTB\Controllers\TeknisaCrud;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\Libs\Service\CRUD as CrudService;
use Zeedhi\Framework\DataSource\ParameterBag;
use Teknisa\CTB\Services\Ctb17000RelatorioRazaoContrapartidaService;

class Ctb17000RelatorioRazaoContrapartidaController extends TeknisaCrud {

    protected $crudService;
    protected $parameterBag;
    protected $environment;
    protected $ctb17000RelatorioRazaoContrapartidaService;

    /**
     * @param CrudService               $crudService
     * @param ParameterBag              $parameterBag
     * @param Environment               $environment
     * @param Ctb17000RelatorioRazaoContrapartidaService $ctb17000RelatorioRazaoContrapartidaService
     */
    public function __construct(CrudService $crudService, ParameterBag $parameterBag, Ctb17000RelatorioRazaoContrapartidaService $ctb17000RelatorioRazaoContrapartidaService) {
        $this->crudService  = $crudService;
        $this->parameterBag = $parameterBag;
        $this->ctb17000RelatorioRazaoContrapartidaService = $ctb17000RelatorioRazaoContrapartidaService;
    }

    /**
     * Gera Razao Oficial
     * @param Row      $row
     * @param Response $response
     */
    public function geraRazaoOficial(Row $request, Response $response) {
        try {
            $row = $request->getRow();
            
            $nrrazao = $this->ctb17000RelatorioRazaoContrapartidaService->geraRazaoOficial(
                $row['CDEMPRESA'], $row['CDCONTCTBLINI'], $row['CDCONTCTBLFIN'], $row['DTINICIAL'], $row['DTFINAL'], 'S'
            );
            
            $response->addDataset(new DataSet('nrrazao', [$nrrazao]));
        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
}
