<?php

namespace Teknisa\CTB\Factories;

use Doctrine\ORM\EntityManager;
use Teknisa\Libs\Util\DateUtil;
use Teknisa\Model\Contabilidade\Entities\Contopectbl;

class Ger09400ParametroContabilFactory{
    
    protected $entityManager;
    protected $connection;

    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }
    
    private function getCopyEmpresaOrigem($empresaOrigem){
        $empresaDestino = new Contopectbl();
        $empresaDestino->setDtiniclanc($empresaOrigem->getDtiniclanc());
        $empresaDestino->setDtfinalanc($empresaOrigem->getDtfinalanc());
        $empresaDestino->setDtinicrela($empresaOrigem->getDtinicrela());
        $empresaDestino->setDtfinarela($empresaOrigem->getDtfinarela());
        $empresaDestino->setDtiniccont($empresaOrigem->getDtiniccont());
        $empresaDestino->setDtfinacont($empresaOrigem->getDtfinacont());
        $empresaDestino->setIdsaldempr($empresaOrigem->getIdsaldempr());
        $empresaDestino->setIdcontgere($empresaOrigem->getIdcontgere());
        $empresaDestino->setIdcontcome($empresaOrigem->getIdcontcome());
        $empresaDestino->setIdcalcsald($empresaOrigem->getIdcalcsald());
        $empresaDestino->setDtinicctbl($empresaOrigem->getDtinicctbl());
        $empresaDestino->setDtfinacctbl($empresaOrigem->getDtfinacctbl());
        $empresaDestino->setDtultatucocb($empresaOrigem->getDtultatucocb());
        $empresaDestino->setDtiniintcontdfe($empresaOrigem->getDtiniintcontdfe());
        $empresaDestino->setDtfinintcontdfe($empresaOrigem->getDtfinintcontdfe());
        $empresaDestino->setDtiniintcontdfs($empresaOrigem->getDtiniintcontdfs());
        $empresaDestino->setDtfinintcontdfs($empresaOrigem->getDtfinintcontdfs());
        $empresaDestino->setIdutcustestcont($empresaOrigem->getIdutcustestcont());
        $empresaDestino->setIdacumvrcont($empresaOrigem->getIdacumvrcont());
        $empresaDestino->setDtiniintcontgpa($empresaOrigem->getDtiniintcontgpa());
        $empresaDestino->setDtfinintcontgpa($empresaOrigem->getDtfinintcontgpa());
        $empresaDestino->setNrorg($empresaOrigem->getNrorg());
        $empresaDestino->setDtinclusao($empresaOrigem->getDtinclusao());
        $empresaDestino->setDtultatu($empresaOrigem->getDtultatu());
        $empresaDestino->setNrorginclusao($empresaOrigem->getNrorginclusao());
        $empresaDestino->setCdoperinclusao($empresaOrigem->getCdoperinclusao());
        $empresaDestino->setNrorgultatu($empresaOrigem->getNrorgultatu());
        $empresaDestino->setCdoperultatu($empresaOrigem->getCdoperultatu());
        $empresaDestino->setIdativo($empresaOrigem->getIdativo());
        $empresaDestino->setIdutsaldosoc($empresaOrigem->getIdutsaldosoc());
        $empresaDestino->setIdsugrat($empresaOrigem->getIdsugrat());
        $empresaDestino->setIdmsmcontadbcr($empresaOrigem->getIdmsmcontadbcr());
        $empresaDestino->setIdconsvnddfs($empresaOrigem->getIdconsvnddfs());
        $empresaDestino->setIdretestsetor($empresaOrigem->getIdretestsetor());
        return $empresaDestino;
    }
    
    public function cadastramentoAutomaticoEmpresaAlteracaoPeriodos($params){
        try{
            // Query a ser executada.
            $sql = "UPDATE CONTOPECTBL
                       SET DTINICLANC = :DTINILANC,
                           DTFINALANC = :DTFINLANC,
                           DTINICRELA = :DTINIRELA,
                           DTFINARELA = :DTFINRELA,
                           DTINICCONT = :DTINIPER,
                           DTFINACONT = :DTFINPER,
                           DTINICCTBL = :DTINIFIN,
                           DTFINACCTBL = :DTFINFIN,
                           DTINIINTCONTDFE = :DTINIDFE,
                           DTFININTCONTDFE = :DTFINDFE,
                           DTINIINTCONTDFS = :DTINIDFS,
                           DTFININTCONTDFS = :DTFINDFS,
                           DTINIINTCONTGPA = :DTINIGPA,
                           DTFININTCONTGPA = :DTFINGPA
                     WHERE CDEMPRESA = :CDEMPRESA";
    
            // Prepara o statement da query para execução.
            $statement = $this->connection->prepare($sql);
    
            // Executa o statement com os paràmetros passados.
            $statement->execute($params);
        }
        catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function cadastramentoAutomaticoEmpresaAlteracaoControles($params){
        try{
            // Query a ser executada.
            $sql = "UPDATE CONTOPECTBL
                       SET IDCONTGERE = :CONTGERE,
                           IDCONTCOME = :CONTCOME,
                           IDUTCUSTESTCONT = :IDUTCUSTEST,
                           IDSUGRAT = :IDSUGRAT,
                           IDUTSALDOSOC = :IDUTSALDOSOC,
                           IDMSMCONTADBCR = :IDMSMCONTA,
                           IDRETESTSETOR = :IDRETESTSETOR,
                           IDCONSVNDDFS = :IDCONSVNDDFS,
                           IDDESPTRIBDIFAL = :IDDESPTRIBDIFAL,
                           IDCONSDTMOVIRETEST = :IDCONSDTMOVIRETEST
                     WHERE CDEMPRESA = :CDEMPRESA";
    
            // Prepara o statement da query para execução.
            $statement = $this->connection->prepare($sql);
    
            // Executa o statement com os paràmetros passados.
            $statement->execute($params);
        }
        catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function validateSaldoPositivo($params){
        try{
            // Query a ser executada.
            $sql = "SELECT CDEMPRESA, TO_CHAR(MIN(DTLANCCONT), 'DD/MM/YYYY') DTSEMEVOLUCAO
                      FROM LANCCONT
                     WHERE CDEMPRESA = :CDEMPRESA
                       AND DTLANCCONT < :DTINICIAL
                       AND NVL(IDLANCSALDO, 'N') <> 'S'
                    GROUP BY CDEMPRESA";
    
            // Prepara o statement da query para execução.
            $statement = $this->connection->prepare($sql);
    
            // Executa o statement com os paràmetros passados.
            $statement->execute($params);

            // Executa um fetch em todos os dados, retornando-os.
            return $statement->fetchAll();
        }
        catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function validateLacnamentoPendenteRecalculo($params){
        try{
            // Query a ser executada.
            $sql = "SELECT S.CDEMPRESA, S.MAIORDATA
                    FROM 
                       (SELECT MAX(DTSALDEMPR) MAIORDATA, CDEMPRESA
                          FROM SALDEMPR
                        GROUP BY CDEMPRESA ) S
                    WHERE (S.CDEMPRESA = :CDEMPRESA)";
    
            // Prepara o statement da query para execução.
            $statement = $this->connection->prepare($sql);
    
            // Executa o statement com os paràmetros passados.
            $statement->execute($params);

            // Executa um fetch em todos os dados, retornando-os.
            return $statement->fetchAll();          
        }
        catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function getContopectbl($cdempresa, $nrorg){
        $params = [ "cdempresa" => $cdempresa, "nrorg" => $nrorg];
        $contopectbl = $this->entityManager->getRepository(Contopectbl::class)->findOneBy($params);
        return $contopectbl;
    }
    
}

